@@ -92,6 +92,7 @@ sub _initialize {
     my $watch_sr = \$watch;
 
     my $each_time = sub {
+        $$watch_sr->want_writeready(0);
 
         $n->($@) if !eval {
             if ( $dbus->initialize() ) {
@@ -100,11 +101,7 @@ sub _initialize {
                 $y->();
             }
             else {
-                my $write_yn = $dbus->init_pending_send();
-                $$watch_sr->configure(
-                    want_readready => !$write_yn,
-                    want_writeready => $write_yn,
-                );
+                $$watch_sr->want_writeready( $dbus->init_pending_send() );
             }
 
             1;
@@ -116,20 +113,11 @@ sub _initialize {
 
         on_read_ready => $each_time,
         on_write_ready => $each_time,
-
-        # It does work to set the read watcher right away, but only
-        # because poll(POLLIN) gives POLLHUP, which IO::Async interprets
-        # as read-ready. Let’s not depend on that.
-        want_readready => 0,
-        want_writeready => 0,
     );
 
     $loop->add($watch);
 
-    # Defer in order to give the caller time to set up promises, etc.
-    $loop->later($each_time);
-
-    return;
+    $each_time->();
 }
 
 sub _set_watches_and_create_messenger {
@@ -154,30 +142,13 @@ sub _set_watches_and_create_messenger {
 
     $self->{'watch_sr'} = $watch_sr = \$watch;
 
-    my $loop = $self->{'loop'};
-
-    $self->{'_give_up_cr'} = sub {
-        $loop->remove($$watch_sr);
-        $$watch_sr = undef;
-    };
-
     return sub {
         $watch->want_writeready( $dbus->pending_send() );
     };
 }
 
-sub _pause {
-    ${ $_[0]->{'watch_sr'} }->want_readready(0);
-}
-
-sub _resume {
-    ${ $_[0]->{'watch_sr'} }->want_readready(1);
-}
-
 sub DESTROY {
-    my $watch_sr = delete $_[0]{'watch_sr'};
-
-    if ($watch_sr && $$watch_sr) {
+    if (my $watch_sr = delete $_[0]{'watch_sr'}) {
         $_[0]{'loop'}->remove($$watch_sr);
         $$watch_sr = undef;
     }
